package com.gentics.portalnode.sdk.imp;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import com.gentics.api.portalnode.imp.AbstractGenticsImp;
import com.gentics.api.portalnode.imp.ImpException;

/**
 * sample imp to format a given text into leet (733t) style, based on a simple
 * alphabet mapping. in order to plug this imp into the portal, one needs to do
 * compile it into the application server classpath, instead of the
 * portletapplication. refer to the infoportal for further information.
 * <ul>
 * <li>create new simple java project</li>
 * <li>move this imp package to a source folder of the new project</li>
 * <li>set the javabuild path to compile into tomcat/shared/classes</li>
 * <li>add imp to portalconfiguration:<br/>
 * 
 * <pre>
 *  &lt;formatter id=&quot;l33t&quot;&gt;
 *   &lt;class-name&gt;com.gentics.portalnode.sdk.L33tImp&lt;/class-name&gt;
 *   &lt;/formatter&gt;
 * </pre>
 * 
 * </li>
 * <li>use imp within a template: $portal.imps.l33t.format("Welcome friend!")</li>
 * <li>restart tomcat</li>
 * </ul>
 */
public class L33tImp extends AbstractGenticsImp {

    private static Map leetAlphabet;

    /**
     * load l33t alphabet
     */
    public void init(String impId, Map parameters) throws ImpException {
        // super init
        super.init(impId, parameters);

        // load dictionary to map characters
        leetAlphabet = new HashMap();
        leetAlphabet.put("f", "ph");
        leetAlphabet.put("a", "@");
        leetAlphabet.put("e", "3");
        leetAlphabet.put("b", "8");
        leetAlphabet.put("s", "z");
        leetAlphabet.put("i", "1");
    }

    /**
     * format the given text into l33t text, using an internal alphabet.
     * @param text any text to l33t, may be null.
     * @return the l33ted text or null if text was null.
     */
    public String format(String text) {

        // handle null text
        if (text == null) {
            return null;
        }

        // get iterator over alphabet
        Iterator it = leetAlphabet.entrySet().iterator();

        // iterate alphabet
        for (Iterator iter = it; iter.hasNext();) {
            Map.Entry element = (Map.Entry) iter.next();
            // replace lower case
            text = text.replaceAll(element.getKey().toString(), element.getValue().toString());
            // replace uppwer case
            text = text.replaceAll(element.getKey().toString().toUpperCase(), element
                    .getValue().toString().toUpperCase());
        }

        return text;
    }
}
